@@ -13,7 +13,7 @@ Usage::
     list_secrets_paginator: ListSecretsPaginator = client.get_paginator("list_secrets")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_secretsmanager.type_defs import ListSecretsResponseTypeDef, PaginatorConfigTypeDef
 
@@ -23,12 +23,12 @@ __all__ = ("ListSecretsPaginator",)
 
 class ListSecretsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
+    [Paginator.ListSecrets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListSecretsResponseTypeDef, None, None]:
+    ) -> Iterator[ListSecretsResponseTypeDef]:
         """
-        [ListSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
+        [ListSecrets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.16/reference/services/secretsmanager.html#SecretsManager.Paginator.ListSecrets.paginate)
         """
